==> qtjambi-charts-debuginfo-windows-x64-6.5.3.jar: sources/QtJambiCharts/QLogValueAxis_shell.h <==
#ifndef QLOGVALUEAXIS_SHELL_H
#define QLOGVALUEAXIS_SHELL_H

#include <QtCore/QtGlobal>
#include <QtCore/qcompilerdetection.h>

QT_WARNING_DISABLE_DEPRECATED

#include <QtCharts/qlogvalueaxis.h>
#include <QtJambi/QtJambiAPI>
#include <QtCharts/qabstractaxis.h>
#include <QtCore/QList>
#include <QtCore/QVariant>
#include <QtCore/qbindingstorage.h>
#include <QtCore/qbytearray.h>
#include <QtCore/qcoreevent.h>
#include <QtCore/qmetaobject.h>
#include <QtCore/qnamespace.h>
#include <QtCore/qobject.h>
#include <QtCore/qproperty.h>
#include <qtcore-config.h>
#if QT_CONFIG(regularexpression)
#include <QtCore/qregularexpression.h>
#endif //QT_CONFIG(regularexpression)
#include <QtCore/qthread.h>
#include <QtCore/qtimer.h>
#include <QtGui/qbrush.h>
#include <QtGui/qcolor.h>
#include <QtGui/qfont.h>
#include <QtGui/qpen.h>
#include <QtJambi/RegistryAPI>


class QLogValueAxis_shell : public QLogValueAxis, public QtJambiShellInterface
{
public:
    QLogValueAxis_shell(QObject* parent0 = nullptr);
    ~QLogValueAxis_shell() override;

    void childEvent(QChildEvent* event0) override;
    void connectNotify(const QMetaMethod& signal0) override;
    void customEvent(QEvent* event0) override;
    void disconnectNotify(const QMetaMethod& signal0) override;
    bool event(QEvent* event0) override;
    bool eventFilter(QObject* watched0, QEvent* event1) override;
    void timerEvent(QTimerEvent* event0) override;
    QAbstractAxis::AxisType type() const override;
    static void operator delete(void * ptr) noexcept;
    const QMetaObject *metaObject() const override final;
    void *qt_metacast(const char *) override final;
    int qt_metacall(QMetaObject::Call, int, void **) override final;
private:
    QtJambiShell* __shell() const override final;
    jmethodID __shell_javaMethod(int pos) const;
};

struct QLogValueAxis_access : public QLogValueAxis
{
    jint __qt_type(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId) const;
};

#endif // QLOGVALUEAXIS_SHELL_H

==> qtjambi-charts-debuginfo-windows-x64-6.5.8.jar: sources/QtJambiCharts/QLogValueAxis_shell.h <==
#ifndef QLOGVALUEAXIS_SHELL_H
#define QLOGVALUEAXIS_SHELL_H

#include <QtCore/QtGlobal>
#include <QtCore/qcompilerdetection.h>

QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wdeprecated-declarations")

#include <QtCharts/qlogvalueaxis.h>
#include <QtJambi/QtJambiAPI>
#include <QtCharts/qabstractaxis.h>
#include <QtCore/QList>
#include <QtCore/QVariant>
#include <QtCore/qbindingstorage.h>
#include <QtCore/qbytearray.h>
#include <QtCore/qcoreevent.h>
#include <QtCore/qmetaobject.h>
#include <QtCore/qnamespace.h>
#include <QtCore/qobject.h>
#include <QtCore/qproperty.h>
#include <qtcore-config.h>
#if QT_CONFIG(regularexpression)
#include <QtCore/qregularexpression.h>
#endif //QT_CONFIG(regularexpression)
#include <QtCore/qthread.h>
#include <QtCore/qtimer.h>
#include <QtGui/qbrush.h>
#include <QtGui/qcolor.h>
#include <QtGui/qfont.h>
#include <QtGui/qpen.h>
#include <QtJambi/RegistryAPI>


class QLogValueAxis_shell : public QLogValueAxis, public QtJambiShellInterface
{
public:
    QLogValueAxis_shell(QObject* parent0 = nullptr);
    ~QLogValueAxis_shell() override;
    static void operator delete(void * ptr) noexcept;
private:
    QtJambiShell* __shell() const override final;
    friend class QLogValueAxis_mshell;
    friend class QLogValueAxis_oshell;
};


class QLogValueAxis_mshell : public QLogValueAxis_shell
{
public:
    using QLogValueAxis_shell::QLogValueAxis_shell;
    static void operator delete(void * ptr) noexcept;
    const QMetaObject *metaObject() const override final;
    void *qt_metacast(const char *) override final;
    int qt_metacall(QMetaObject::Call, int, void **) override final;
};


class QLogValueAxis_oshell : public QLogValueAxis_mshell
{
public:
    using QLogValueAxis_mshell::QLogValueAxis_mshell;
    void childEvent(QChildEvent* event0) override;
    void connectNotify(const QMetaMethod& signal0) override;
    void customEvent(QEvent* event0) override;
    void disconnectNotify(const QMetaMethod& signal0) override;
    bool event(QEvent* event0) override;
    bool eventFilter(QObject* watched0, QEvent* event1) override;
    void timerEvent(QTimerEvent* event0) override;
    QAbstractAxis::AxisType type() const override;
    static void operator delete(void * ptr) noexcept;
private:
    jmethodID __shell_javaMethod(int pos) const;
};

struct QLogValueAxis_access : public QLogValueAxis
{
    jint __qt_type_constfct(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId) const;
};

#endif // QLOGVALUEAXIS_SHELL_H
